@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from dcicutils.ff_utils import get_metadata
-from tibanna.utils import _tibanna_settings, printlog
+from tibanna import create_logger
+from tibanna.utils import _tibanna_settings
 # from tibanna_4dn.vars import TIBANNA_DEFAULT_STEP_FUNCTION_NAME
 from tibanna_4dn.core import API
 from tibanna_ffcommon.exceptions import TibannaStartException, FdnConnectionException
@@ -12,6 +13,9 @@ from tibanna_ffcommon.portal_utils import (
 from tibanna_4dn.vars import AWS_REGION, LAMBDA_TYPE, BUCKET_NAME
 
 
+logger = create_logger(__name__)
+
+
 config = {
     'function_name': 'validate_md5_s3_initiator_' + LAMBDA_TYPE,
     'function_module': 'service',
@@ -123,7 +127,7 @@ def get_file_format(meta, object_key, ff_keys):
     file_format, extra_formats = get_fileformats_for_accession(meta)
     if file_format:
         fe_map = FormatExtensionMap(ff_keys)
-        printlog(fe_map)
+        logger.debug("fe_map= " + str(fe_map))
         if extension == fe_map.get_extension(file_format):
             return (file_format, None)
         elif extension in fe_map.get_other_extensions(file_format):
@@ -172,11 +176,11 @@ def make_input(event, wf='md5', dependency=None, run_name_prefix='validate'):
     if 'prod' in env:
         env = 'data'
 
-    run_name = run_name_prefix + "_%s" % (upload_key.split('/')[1].split('.')[0])
+    run_name = run_name_prefix + "_%s" % (object_key.split('.')[0])
     if event.get('run_name'):
         run_name = event.get('run_name')  # used for testing
 
-    return _make_input(env, bucket, wf, object_key, uuid, run_name, dependency)
+    return _make_input(env, wf, object_key, uuid, run_name, dependency)
 
 
 _workflows = {'md5':
@@ -190,8 +194,7 @@ _workflows = {'md5':
               }
 
 
-def _make_input(env, bucket, workflow, object_key, uuid, run_name, dependency=None):
-    output_bucket = BUCKET_NAME(env, 'FileProcessed')
+def _make_input(env, workflow, object_key, uuid, run_name, dependency=None):
     workflow_uuid = _workflows[workflow]['uuid']
     workflow_arg_name = _workflows[workflow]['arg_name']
 
@@ -200,16 +203,12 @@ def _make_input(env, bucket, workflow, object_key, uuid, run_name, dependency=No
             "workflow_uuid": workflow_uuid,
             "input_files": [
                 {"workflow_argument_name": workflow_arg_name,
-                 "bucket_name": bucket,
                  "uuid": uuid,
-                 "object_key": object_key,
                  "mount": True
                  }
              ],
-            "output_bucket": output_bucket,
             "config": {
-                "ebs_type": "gp2",
-                "ebs_iops": "",
+                "instance_type": "t3.small",
                 "ebs_size": 10,
                 "shutdown_min": 0,
                 "log_bucket": "tibanna-output",
